@@ -254,7 +254,7 @@ test_that("Gegen_norm_2d with unnormalized coefficients", {
                sum(w_k * f_2_11(th_k, th_k)^2 * sin_k^9))
 })
 
-test_that("Bounds Gegenbauer polynomials", {
+test_that("Bound for Gegenbauer polynomials", {
 
   x <- seq(-1, 1, l = 200)
   for (p in c(3, 4, 5, 100)) {
@@ -264,6 +264,25 @@ test_that("Bounds Gegenbauer polynomials", {
           (2 * (1 - x^2)^(-(p - 2) / 4) * gamma(k + (p - 2) / 2) /
              (gamma((p - 2) / 2) * gamma(k + 1)))
       ))
+      expect_true(all(
+        abs(Gegen_polyn(theta = acos(x), k = k, p = p)) <
+          (2 * (1 - x^2)^(-(p - 2) / 4) * gamma(k + (p - 2) / 2) /
+             (gamma((p - 2) / 2) * gamma(k + 1)))
+      ))
+    }
+  }
+
+})
+
+test_that("Gegenbauer polynomials are bounded by their value at 1", {
+
+  x <- seq(-1, 1, l = 200)
+  for (p in c(3, 4, 5, 100)) {
+    for (k in c(1:3, 10, 50, 100)) {
+      expect_true(all(
+        abs(Gegen_polyn(theta = acos(x), k = k, p = p)) <=
+          drop(Gegen_polyn(theta = acos(1), k = k, p = p))
+      ))
     }
   }
 
